@@ -9,6 +9,8 @@ from dynaconf.loaders import toml_loader
 from dynaconf.loaders import yaml_loader
 from dynaconf.utils import deduplicate
 from dynaconf.utils import ensure_a_list
+from dynaconf.utils.boxing import DynaBox
+from dynaconf.utils.files import get_local_filename
 from dynaconf.utils.parse_conf import false_values
 
 
@@ -29,12 +31,12 @@ def default_loader(obj, defaults=None):
     for key in all_keys:
         if not obj.exists(key):
             value = defaults.get(key, default_settings_values.get(key))
-            obj.logger.debug("loading: %s:%s", key, value)
             obj.set(key, value)
 
     # start dotenv to get default env vars from there
     # check overrides in env vars
-    default_settings.start_dotenv(obj)
+    if obj.get("load_dotenv") is True:
+        default_settings.start_dotenv(obj)
 
     # Deal with cases where a custom ENV_SWITCHER_IS_PROVIDED
     # Example: Flask and Django Extensions
@@ -52,7 +54,6 @@ def default_loader(obj, defaults=None):
         )
 
         if env_value != "_not_found":
-            obj.logger.debug("overriding from envvar: %s:%s", key, env_value)
             obj.set(key, env_value, tomlfy=True)
 
 
@@ -81,6 +82,7 @@ def settings_loader(
     found_files = []
     modules_names = []
     for item in files:
+        item = str(item)  # Ensure str in case of LocalPath/Path is passed.
         if item.endswith(ct.ALL_EXTENSIONS + (".py",)):
             p_root = obj._root_path or (
                 os.path.dirname(found_files[0]) if found_files else None
@@ -94,6 +96,15 @@ def settings_loader(
 
     enabled_core_loaders = obj.get("CORE_LOADERS_FOR_DYNACONF")
 
+    # add `.local.` to found_files list to search for local files.
+    found_files.extend(
+        [
+            get_local_filename(item)
+            for item in found_files
+            if ".local." not in str(item)
+        ]
+    )
+
     for mod_file in modules_names + found_files:
         # can be set to multiple files settings.py,settings.yaml,...
 
@@ -142,13 +153,13 @@ def settings_loader(
             global_filename = tmpl.format("global", filename, extension)
             global_mod_file = os.path.join(dirname, global_filename)
         else:
-            env_mod_file = "{0}_{1}".format(env.lower(), mod_file)
-            global_mod_file = "{0}_{1}".format("global", mod_file)
+            env_mod_file = f"{env.lower()}_{mod_file}"
+            global_mod_file = f"global_{mod_file}"
 
         py_loader.load(
             obj,
             env_mod_file,
-            identifier="py_{0}".format(env.upper()),
+            identifier=f"py_{env.upper()}",
             silent=True,
             key=key,
         )
@@ -164,13 +175,24 @@ def enable_external_loaders(obj):
     looks forenv variables like `REDIS_ENABLED_FOR_DYNACONF`
     """
     for name, loader in ct.EXTERNAL_LOADERS.items():
-        enabled = getattr(
-            obj, "{}_ENABLED_FOR_DYNACONF".format(name.upper()), False
-        )
+        enabled = getattr(obj, f"{name.upper()}_ENABLED_FOR_DYNACONF", False)
         if (
             enabled
             and enabled not in false_values
             and loader not in obj.LOADERS_FOR_DYNACONF
         ):  # noqa
-            obj.logger.debug("loaders: Enabling %s", loader)
             obj.LOADERS_FOR_DYNACONF.insert(0, loader)
+
+
+def write(filename, data, env=None):
+    """Writes `data` to `filename` infers format by file extension."""
+    loader_name = f"{filename.rpartition('.')[-1]}_loader"
+    loader = globals().get(loader_name)
+    if not loader:
+        raise IOError(f"{loader_name} cannot be found.")
+
+    data = DynaBox(data).to_dict()
+    if loader is not py_loader and env and env not in data:
+        data = {env: data}
+
+    loader.write(filename, data, merge=False)
